@@ -26,4 +26,4 @@
 // We don't want to waste those seconds for each cpp file, so we
 // use this precompiled header.
 #include <boost/python.hpp>
-#include <tango.h>
+#include <tango/tango.h>
